@@ -1,23 +1,23 @@
 /*
  * SPDX-FileCopyrightText: (C) 2020 Carl Schwan <carl@carlschwan.eu>
- * 
+ *
  * SPDX-LicenseRef: GPL-3.0-or-later
  */
+#include "config-kontrast.h"
+#include "savedcolormodel.h"
+#include <KAboutData>
+#include <KLocalizedContext>
+#include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QQmlApplicationEngine>
-#include <QtQml>
-#include <QUrl>
 #include <QIcon>
+#include <QQmlApplicationEngine>
 #include <QSqlDatabase>
 #include <QSqlError>
 #include <QSqlQuery>
-#include <KLocalizedContext>
-#include <KAboutData>
-#include <KLocalizedString>
+#include <QUrl>
+#include <QtQml>
 #include <kontrast.h>
-#include "savedcolormodel.h"
-#include "config-kontrast.h"
 
 const QString DRIVER(QStringLiteral("QSQLITE"));
 
@@ -26,12 +26,17 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("kontrast");
-    
-    KAboutData aboutData(QStringLiteral("kontrast"), i18nc("@title", "Kontrast"), QStringLiteral(KONTRAST_VERSION_STRING),
+
+    KAboutData aboutData(QStringLiteral("kontrast"),
+                         i18nc("@title", "Kontrast"),
+                         QStringLiteral(KONTRAST_VERSION_STRING),
                          i18nc("@title", "A contrast checker application"),
                          KAboutLicense::GPL_V3);
-    
-    aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"), i18nc("@info:credit", "Maintainer and creator"), QStringLiteral("carl@carlschwan.eu"), QStringLiteral("https://carlschwan.eu"));
+
+    aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
+                        i18nc("@info:credit", "Maintainer and creator"),
+                        QStringLiteral("carl@carlschwan.eu"),
+                        QStringLiteral("https://carlschwan.eu"));
     aboutData.addCredit(i18nc("@info:credit", "Wikipedia"), i18nc("@info:credit", "Text on the main page CC-BY-SA-4.0"));
     aboutData.addAuthor(i18nc("@info:credit", "Carson Black"), i18nc("@info:credit", "SQLite backend for favorite colors"));
 
@@ -56,7 +61,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     kontrast.random();
 
     QQmlApplicationEngine engine;
-    
+
     qmlRegisterSingletonInstance("org.kde.kontrast.private", 1, 0, "Kontrast", &kontrast);
     qmlRegisterSingletonInstance("org.kde.kontrast.private", 1, 0, "ColorStore", new SavedColorModel(qApp));
 
