@@ -1,7 +1,7 @@
 /*
  * SPDX-FileCopyrightText: (C) 2020 Carl Schwan <carl@carlschwan.eu>
  * SPDX-FileCopyrightText: (C) 2020 Carson Black <uhhadd@gmail.com>
- * 
+ *
  * SPDX-LicenseRef: GPL-3.0-or-later
  */
 
@@ -16,25 +16,25 @@
 struct ColorCombination {
     QColor textColor;
     QColor backgroundColor;
-    
+
     ColorCombination(QColor textColor, QColor backgroundColor)
         : textColor(textColor)
         , backgroundColor(backgroundColor)
-    {}
+    {
+    }
 };
-    
 
 /**
  * @brief Store all the user's favorite color combinations.
  */
-class SavedColorModel : public  QSqlTableModel
+class SavedColorModel : public QSqlTableModel
 {
     Q_OBJECT
 
 public:
     enum ColorRoles {
         TextColor = Qt::UserRole + 1,
-        BackgroundColor
+        BackgroundColor,
     };
 
 public:
@@ -45,7 +45,7 @@ public:
     QHash<int, QByteArray> roleNames() const override;
     QVariant data(const QModelIndex &index, int role) const override;
 
-    Q_INVOKABLE bool addColor(const QString& name, const QColor& foreground, const QColor& background);
+    Q_INVOKABLE bool addColor(const QString &name, const QColor &foreground, const QColor &background);
     Q_INVOKABLE bool removeColor(int index);
 
 private:
